@@ -115,6 +115,29 @@ class LarkDocs(Lark):
         url = self.SHEETS_INFO.format(**{"SHEET_TOKEN": sheet_token,})
         return self.get(url)
 
+    def get_sheet_info_by_sheet_id(self, sheet_token, sheet_id):
+        """获取指定子表的信息 如果没有找到则会返回 None 类型
+
+        Args:
+            sheet_token (str): 表的 Token
+            sheet_id (str): 子表名
+
+        Returns:
+            sheets: {
+                    "sheetId": "***",
+                    "title": "***",
+                    "index": 0,
+                    "rowCount": 0,
+                    "columnCount": 0
+                }
+        """
+        sheets_info = self.get_sheet_info(sheet_token)
+        # 获取符合要求的 sheet
+        goal_sheets = list(
+            filter(lambda x: x["sheetId"] == sheet_id, sheets_info["sheets"])
+        )
+        return goal_sheets.pop() if goal_sheets else None
+
     @post_request(larkDockError)
     def create_docs(self, folder_token, title, docs_type="sheet"):
         """创建文档
@@ -367,6 +390,31 @@ class LarkDocs(Lark):
             },
         )
 
+    @post_request(larkDockError)
+    def update_sheet_name(self, sheet_token, sheet_id, sheet_title):
+        """更改子表的名字 注意重名的 sheets 会报错失败
+
+        Args:
+            sheet_token (str): sheet_token
+            sheet_id (str): sheet_id 子表的 id
+            sheet_title (str): 要修改的子表名字
+        """
+        url = "https://open.feishu.cn/open-apis/sheet/v2/spreadsheets/{}/sheets_batch_update".format(
+            sheet_token
+        )
+        return self.post(
+            url,
+            json={
+                "requests": [
+                    {
+                        "updateSheet": {
+                            "properties": {"sheetId": sheet_id, "title": sheet_title}
+                        }
+                    }
+                ]
+            },
+        )
+
     @post_request(larkDockError)
     def get_root_folder_metadata(self):
         """获取 "我的空间" 的元信息
